#!/usr/bin/env python
# -*- coding: utf-8  -*-
# Script en Python que organiza los ficheros del directorio
# de trabajo en función de su nombre completo.
 
# USO CORRECTO: python organizar.py [-v] [-h|-s|-f]
#   * -v -> modo chivato activado
#   * -h o --help -> ayuda
#   * -s o --secure -> copia los ficheros en lugar de
#                      moverlos
#   * -f o --force -> fuerza el traslado de los ficheros,
#                     si existen se borran

# Creado por Noelia Sales Montes
 
# Este programa es software libre. Puede redistribuirlo 
# y/o modificarlo bajo los términos de la Licencia Pública 
# General (GPL) de GNU según es publicada por la Free 
# Software Foundation, sea de la versión 2 de dicha Licencia 
# o posteriores.
 
# Este programa se distribuye con la esperanza de que sea 
# útil, pero SIN NINGUNA GARANTIA, incluso sin la garantía 
# MERCANTIL implicita o sin garantizar la CONVENIENCIA PARA 
# UN PROPOSITO PARTICULAR. Véase la Licencia Publica General 
# de GNU para más detalles.
 
# Contacto:  
#            noelia.salesmontes@gmail.com 
 
import sys
import os
import shutil
import getopt
import glob
import re

# Expresiones regulares de los archivos a procesar 
exreg=['*.mp3','*.hs','*.py']
# Directorios que corresponden a cada archivo que se corresponda
# con las expresiones anteriores
dirs=['/home/nessa/Musica','/home/nessa/Haskell','/home/nessa/Python']
# Opciones
verbose=False
seguro=False
force=False

def usage():
    print "USO CORRECTO: python organizar.py [-v] [-h|-s|-f]"

def organizar():
    indice = 0
    # Para cada expresión regular
    for e in exreg:
        # Modo chivato
        if verbose == True:
            print "Expresión regular: "+e
        
        # Encuentra los ficheros que coincidan con e
        for f in glob.glob(e):
            # Asegura que exista el directorio de traslado
            if not os.path.exists(dirs[indice]):
                if verbose == True:
                    print "Creando "+dirs[indice]
                os.makedirs(dirs[indice])

            if verbose == True:
                print f+" => "+dirs[indice]

            # Copia (modo seguro) o movimiento
            try:
                if seguro == True:                
                    shutil.copy(f, dirs[indice])
                else:
                    shutil.move(f, dirs[indice])
            except:
                # Si hay problemas, se fuerza el traslado
                if force == True:
                    try:
                        os.remove(os.path.join(dirs[indice],f))
                        print os.path.join(dirs[indice],f)
                        if seguro == True:
                            shutil.copy(f, dirs[indice])
                        else:
                            shutil.move(f, dirs[indice])
                    except:
                        print f+" no ha sido trasladado"
                else:
                    print f+" no ha sido trasladado"
        indice+=1


if __name__ == "__main__":
    try:
        opts, args = getopt.getopt(sys.argv[1:], 'shvf',["secure","help","force"])
    except getopt.GetoptError, err:
        # Imprimir error y ayuda y salir
        print str(err)
        usage()
        sys.exit(2)

    # Identificar opciones
    for o, a in opts:
        if o == "-v":
            verbose = True
        elif o in ("-h", "--help"):
            usage()
            sys.exit()
        elif o in ("-s", "--secure"):
            seguro = True
        elif o in ("-f", "--force"):
            force = True
        else:
            assert False, "Opción no manejada"
    
    organizar()
